@@ -27,15 +27,15 @@
 #include "Telescope.hpp"
 
 #include <QFont>
+#include <QSettings>
 
 #define MIN_OCULARS_INI_VERSION 0.12
 
 QT_BEGIN_NAMESPACE
-class QSqlTableModel;
 class QKeyEvent;
 class QMouseEvent;
 class QPixmap;
-class QSqlQuery;
+class QSettings;
 QT_END_NAMESPACE
 
 class StelButton;
@@ -48,6 +48,7 @@ class Oculars : public StelModule
 public:
 	Oculars();
 	virtual ~Oculars();
+	static QSettings* appSettings();
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods defined in the StelModule class
@@ -56,15 +57,14 @@ public:
 	virtual bool configureGui(bool show=true);
 	virtual void draw(StelCore* core);
 	virtual double getCallOrder(StelModuleActionName actionName) const;
-//	virtual void handleKeys(class QKeyEvent* event);
+	//! Returns the module-specific style sheet.
+	//! The main StelStyle instance should be passed.
+	virtual const StelStyle getModuleStyleSheet(const StelStyle& style);
+	//	virtual void handleKeys(class QKeyEvent* event);
 	virtual void handleMouseClicks(class QMouseEvent* event);
 	virtual void setStelStyle(const QString& style);
 	virtual void update(double) {;}
 
-	//! Returns the module-specific style sheet.
-	//! The main StelStyle instance should be passed.
-	const StelStyle getModuleStyleSheet(const StelStyle& style);
-
 public slots:
 	//! This method is called with we detect that our hot key is pressed.  It handles
 	//! determining if we should do anything - based on a selected object - and painting
@@ -89,10 +89,7 @@ signals:
 private slots:
 	//! Signifies a change in ocular or telescope.  Sets new zoom level.
 	void instrumentChanged();
-	void determineMaxImageCircle();
-	void loadCCDs();
-	void loadOculars();
-	void loadTelescopes();
+	void determineMaxEyepieceAngle();
 	void setScaleImageCircle(bool state);
 
 private:
@@ -102,10 +99,6 @@ private:
 	//! Renders the three Telrad circles, but only if not in ocular mode.
 	void drawTelrad();
 
-	//! Insures that each required table exists in the database, as well as instantiate the table models.
-	//! @return true if the DB was correctly initialized, false if it was not.
-	bool initializeDB();
-	
 	//! Set up the Qt actions needed to activate the plugin.
 	void initializeActivationActions();
 	
@@ -117,8 +110,6 @@ private:
 	//! while flagShowOculars == true.
 	void interceptMovementKey(class QKeyEvent* event);
 
-	void loadDatabaseObjects();
-
 	//! Paint the mask into the viewport.
 	void paintMask();
 	
@@ -134,7 +125,8 @@ private:
 	//! ends.  However, if one does exist, it opens it, and looks for the oculars_version key.  The value (or even
 	//! presence) is used to determine if the ini file is usable.  If not, it is renamed, and a new one copied over.
 	//! It does not ty to cope values over.
-	void validateIniFile();
+	//! Once there is a valid ini file, it is loaded into the settings attribute.
+	void validateAndLoadIniFile();
 
 	//! Recordd the state of the GridLinesMgr views beforehand, so that it can be reset afterwords.
 	//! @param rezoom if true, this zoom operation is starting from an already zoomed state.
@@ -145,7 +137,7 @@ private:
 	void zoomOcular();
 
 	//! A list of all the oculars defined in the ini file.  Must have at least one, or module will not run.
-	QList<CCD *> CCDs;
+	QList<CCD *> ccds;
 	QList<Ocular *> oculars;
 	QList<Telescope *> telescopes;
 	int selectedCCDIndex;
@@ -157,6 +149,7 @@ private:
 	bool flagShowCrosshairs;	//!< flag used to track in crosshairs should be rendered in the ocular view.
 	bool flagShowTelrad;		//!< If true, display the Telrad overlay.
 	int usageMessageLabelID;	//!< the id of the label showing the usage message. -1 means it's not displayed.
+	int noEntitiesLabelID;	//!< the id of the label showing that there are no telescopes or oclars. -1 means it's not displayed.
 
 	bool flagAzimuthalGrid;		//!< Flag to track if AzimuthalGrid was displayed at activation.
 	bool flagEquatorGrid;		//!< Flag to track if EquatorGrid was displayed at activation.
@@ -165,8 +158,8 @@ private:
 	bool flagEclipticLine;		//!< Flag to track if EclipticLine was displayed at activation.
 	bool flagMeridianLine;		//!< Flag to track if MeridianLine was displayed at activation.
 
-	double maxImageCircle;		//!< The maximum image circle for all eyepieces.  Used to scale the mask.
-	bool useMaxImageCircle;		//!< Read from the ini file, whether to scale the mask based on exit circle size.
+	double maxEyepieceAngle;	//!< The maximum aFOV of any eyepiece.
+	bool useMaxEyepieceAngle;	//!< Read from the ini file, whether to scale the mask based aFOV.
 
 
 	// for toolbar button
@@ -180,10 +173,6 @@ private:
 	bool ready; //!< A flag that determines that this module is usable.  If false, we won't open.
 	bool newInstrument; //!< true the first time draw is called for a new ocular or telescope, false otherwise.
 
-	QSqlTableModel *CCDsTableModel;
-	QSqlTableModel *ocularsTableModel;
-	QSqlTableModel *telescopesTableModel;
-
 	//Styles
 	QByteArray normalStyleSheet;
 	QByteArray nightStyleSheet;
