@@ -23,10 +23,20 @@
 #include <QVariant>
 #include <QString>
 #include <QStringList>
+#include <QFont>
+#include <QList>
+#include <QDateTime>
 
 #include "StelObject.hpp"
 #include "StelTextureTypes.hpp"
-#include "sgp4sdp4/sgp4sdp4.h"
+#include "StelSphereGeometry.hpp"
+
+#include "StelPainter.hpp"
+#include "gsatellite/gSatTEME.hpp"
+#include "gsatellite/gObserver.hpp"
+#include "gsatellite/gTime.hpp"
+#include "gsatellite/gVector.hpp"
+
 
 class StelPainter;
 class StelLocation;
@@ -76,32 +86,77 @@ public:
 	virtual QString getNameI18n(void) const {return designation;}
 	virtual QString getEnglishName(void) const {return designation;}
 	
+	//! Set new tleElements.  This assumes the designation is already set, populates
+	//! the tleElements values and configures internal orbit parameters.
+	void setNewTleElements(const QString& tle1, const QString& tle2);
+
 	// calculate faders, new position
 	void update(double deltaTime);
 
 	double getDoppler(double freq) const;
 	static float showLabels;
+	static double roundToDp(float n, int dp);
+
+	// when the observer location changes we need to
+	void recalculateOrbitLines(void);
+
+public:
+	void enableDrawOrbit(bool b);
+
+private:
+	//draw orbits methods
+	void computeOrbitPoints();
+	void drawOrbit(StelPainter& painter);
+	//! returns 0 - 1.0 for the DRAWORBIT_FADE_NUMBER segments at
+	//! each end of an orbit, with 1 in the middle.
+	float calculateOrbitSegmentIntensity(int segNum);
+	void setNightColors(bool night);
 
 private:
 	bool initialized;
 	bool visible;
+	bool orbitVisible;  //draw orbit enabled/disabled
+
 	QString designation;               // The ID of the satllite
 	QString description;               // longer description of spacecraft
 	Vec3d XYZ;                         // holds J2000 position
-	char elements[3][80];              // TLE elements as char* for passing to sgp lib
-	tle_t tle, localtle;
+	QPair< QByteArray, QByteArray > tleElements;
 	double height, velocity, azimuth, elevation, range, rangeRate;
 	QList<commLink> comms;
 	Vec3f hintColor;
 	QStringList groupIDs;
+	QDateTime lastUpdated;
 	
 	static StelTextureSP hintTexture;
 	static float hintBrightness;
 	static float hintScale;
-	geodetic_t obs_geodetic;           // observer location
+	static SphericalCap viewportHalfspace;
+	static int orbitLineSegments;
+	static int orbitLineFadeSegments;
+	static int orbitLineSegmentDuration;
+	static bool orbitLinesFlag;
 
 	void draw(const StelCore* core, StelPainter& painter, float maxMagHints);
 	void setObserverLocation(StelLocation* loc=NULL);
+
+
+	//gsatellite objects
+	gSatTEME *pSatellite;
+	gObserver observer;
+	gTime     epochTime;
+	gVector   Position;
+	gVector   Vel;
+	gVector   LatLong;
+	gVector   azElPos;
+
+	//Satellite Orbit Draw
+	QFont     font;
+	Vec3f     orbitColorNormal;
+	Vec3f     orbitColorNight;
+	Vec3f*    orbitColor;
+	gTime     lastEpochCompForOrbit;
+	QList<gVector> orbitPoints; //orbit points represented by azElPos vectors
+
 };
 
 #endif // _SATELLITE_HPP_ 
