@@ -72,10 +72,10 @@ StelPluginInfo TelescopeControlStelPluginInterface::getPluginInfo() const
 
 	StelPluginInfo info;
 	info.id = "TelescopeControl";
-	info.displayedName = "Telescope Control";
+	info.displayedName = q_("Telescope Control");
 	info.authors = "Bogdan Marinov, Johannes Gajdosik";
 	info.contact = "http://stellarium.org";
-	info.description = "This plug-in allows Stellarium to send \"slew\" commands to a telescope on a computerized mount (a \"GoTo telescope\").";
+	info.description = q_("This plug-in allows Stellarium to send \"slew\" commands to a telescope on a computerized mount (a \"GoTo telescope\").");
 	return info;
 }
 
@@ -142,70 +142,29 @@ void TelescopeControl::init()
 		reticleTexture = StelApp::getInstance().getTextureManager().createTexture(":/telescopeControl/telescope_reticle.png");
 		selectionTexture = StelApp::getInstance().getTextureManager().createTexture("textures/pointeur2.png");
 		
-		//Load the module's custom style sheets
-		QFile styleSheetFile;
-		styleSheetFile.setFileName(":/telescopeControl/normalStyle.css");
-		if(styleSheetFile.open(QFile::ReadOnly|QFile::Text))
-		{
-			normalStyleSheet = new QByteArray(styleSheetFile.readAll());
-		}
-		styleSheetFile.close();
-		styleSheetFile.setFileName(":/telescopeControl/nightStyle.css");
-		if(styleSheetFile.open(QFile::ReadOnly|QFile::Text))
-		{
-			nightStyleSheet = new QByteArray(styleSheetFile.readAll());
-		}
-		styleSheetFile.close();
-		
 		StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 		
 		//Create telescope key bindings
 		 /* QAction-s with these key bindings existed in Stellarium prior to
 			revision 6311. Any future backports should account for that. */
 		QString group = N_("Telescope Control");
+		for (int i = MIN_SLOT_NUMBER; i <= MAX_SLOT_NUMBER; i++)
+		{
+			// "Slew to object" commands
+			QString name = QString("actionMove_Telescope_To_Selection_%1").arg(i);
+			QString description = q_("Move telescope #%1 to selected object").arg(i);
+			QString shortcut = QString("Ctrl+%1").arg(i);
+			gui->addGuiActions(name, description, shortcut, group, false, false);
+			connect(gui->getGuiActions(name), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
 
-		// "Slew to object" commands
-		gui->addGuiActions("actionMove_Telescope_To_Selection_1", N_("Move telescope #1 to selected object"), "Ctrl+1", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_2", N_("Move telescope #2 to selected object"), "Ctrl+2", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_3", N_("Move telescope #3 to selected object"), "Ctrl+3", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_4", N_("Move telescope #4 to selected object"), "Ctrl+4", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_5", N_("Move telescope #5 to selected object"), "Ctrl+5", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_6", N_("Move telescope #6 to selected object"), "Ctrl+6", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_7", N_("Move telescope #7 to selected object"), "Ctrl+7", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_8", N_("Move telescope #8 to selected object"), "Ctrl+8", group, false, false);
-		gui->addGuiActions("actionMove_Telescope_To_Selection_9", N_("Move telescope #9 to selected object"), "Ctrl+9", group, false, false);
-
-		// "Slew to the center of the screen" commands
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_1", N_("Move telescope #1 to the point currently in the center of the screen"), "Alt+1", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_2", N_("Move telescope #2 to the point currently in the center of the screen"), "Alt+2", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_3", N_("Move telescope #3 to the point currently in the center of the screen"), "Alt+3", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_4", N_("Move telescope #4 to the point currently in the center of the screen"), "Alt+4", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_5", N_("Move telescope #5 to the point currently in the center of the screen"), "Alt+5", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_6", N_("Move telescope #6 to the point currently in the center of the screen"), "Alt+6", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_7", N_("Move telescope #7 to the point currently in the center of the screen"), "Alt+7", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_8", N_("Move telescope #8 to the point currently in the center of the screen"), "Alt+8", group, false, false);
-		gui->addGuiActions("actionSlew_Telescope_To_Direction_9", N_("Move telescope #9 to the point currently in the center of the screen"), "Alt+9", group, false, false);
-		
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_1"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_2"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_3"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_4"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_5"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_6"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_7"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_8"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-		connect(gui->getGuiActions("actionMove_Telescope_To_Selection_9"), SIGNAL(triggered()), this, SLOT(slewTelescopeToSelectedObject()));
-
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_1"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_2"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_3"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_4"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_5"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_6"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_7"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_8"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		connect(gui->getGuiActions("actionSlew_Telescope_To_Direction_9"), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
-		
+			// "Slew to the center of the screen" commands
+			name = QString("actionSlew_Telescope_To_Direction_%1").arg(i);
+			description = q_("Move telescope #%1 to the point currently in the center of the screen").arg(i);
+			shortcut = QString("Alt+%1").arg(i);
+			gui->addGuiActions(name, description, shortcut, group, false, false);
+			connect(gui->getGuiActions(name), SIGNAL(triggered()), this, SLOT(slewTelescopeToViewDirection()));
+		}
+	
 		//Create and initialize dialog windows
 		telescopeDialog = new TelescopeDialog();
 		slewDialog = new SlewDialog();
@@ -337,7 +296,6 @@ void TelescopeControl::setStelStyle(const QString& section)
 	}
 
 	telescopeDialog->updateStyle();
-	slewDialog->updateStyle();
 }
 
 double TelescopeControl::getCallOrder(StelModuleActionName actionName) const
@@ -781,7 +739,7 @@ void TelescopeControl::loadTelescopes()
 
 			QVariantMap telescope = node.value().toMap();
 
-			//Essential parameters: Name and connection type
+			//Essential parameters: Name, connection type, equinox
 			//Validation: Name
 			QString name = telescope.value("name").toString();
 			if(name.isEmpty())
@@ -801,6 +759,14 @@ void TelescopeControl::loadTelescopes()
 			}
 			ConnectionType connectionType = connectionTypeNames.key(connection);
 
+			QString equinox = telescope.value("equinox", "J2000").toString();
+			if (equinox != "J2000" && equinox != "JNow")
+			{
+				qDebug() << "TelescopeControl: Unable to load telescope: Invalid equinox value at slot" << key;
+				map.remove(key);
+				continue;
+			}
+
 			QString hostName("localhost");
 			int portTCP = 0;
 			int delay = 0;
@@ -906,7 +872,7 @@ void TelescopeControl::loadTelescopes()
 					//Use a sever if necessary
 					if(deviceModels[deviceModelName].useExecutable)
 					{
-						if(startClientAtSlot(slot, connectionType, name, hostName, portTCP, delay, internalCircles))
+						if(startClientAtSlot(slot, connectionType, name, equinox, hostName, portTCP, delay, internalCircles))
 						{
 
 							if(!startServerAtSlot(slot, deviceModelName, portTCP, portSerial))
@@ -918,26 +884,32 @@ void TelescopeControl::loadTelescopes()
 						else
 						{
 							qDebug() << "TelescopeControl: Unable to create a telescope client at slot" << slot;
-							continue;
+							//Unnecessary due to if-else construction;
+							//also, causes bug #608533
+							//continue;
 						}
 					}
 					else
 					{
 						addLogAtSlot(slot);
 						logAtSlot(slot);
-						if(!startClientAtSlot(slot, connectionType, name, QString(), 0, delay, internalCircles, deviceModelName, portSerial))
+						if(!startClientAtSlot(slot, connectionType, name, equinox, QString(), 0, delay, internalCircles, deviceModelName, portSerial))
 						{
 							qDebug() << "TelescopeControl: Unable to create a telescope client at slot" << slot;
-							continue;
+							//Unnecessary due to if-else construction;
+							//also, causes bug #608533
+							//continue;
 						}
 					}
 				}
 				else
 				{
-					if(!startClientAtSlot(slot, connectionType, name, hostName, portTCP, delay, internalCircles))
+					if(!startClientAtSlot(slot, connectionType, name, equinox, hostName, portTCP, delay, internalCircles))
 					{
 						qDebug() << "TelescopeControl: Unable to create a telescope client at slot" << slot;
-						continue;
+						//Unnecessary due to if-else construction;
+						//also, causes bug #608533
+						//continue;
 					}
 				}
 			}
@@ -960,16 +932,17 @@ void TelescopeControl::loadTelescopes()
 	telescopeDescriptions = result;
 }
 
-bool TelescopeControl::addTelescopeAtSlot(int slot, ConnectionType connectionType, QString name, QString host, int portTCP, int delay, bool connectAtStartup, QList<double> circles, QString deviceModelName, QString portSerial)
+bool TelescopeControl::addTelescopeAtSlot(int slot, ConnectionType connectionType, QString name, QString equinox, QString host, int portTCP, int delay, bool connectAtStartup, QList<double> circles, QString deviceModelName, QString portSerial)
 {
 	//Validation
-	if(!isValidSlotNumber(slot) || name.isEmpty() || connectionType <= ConnectionNA || connectionType >= ConnectionCount)
+	if(!isValidSlotNumber(slot) || name.isEmpty() || equinox.isEmpty() || connectionType <= ConnectionNA || connectionType >= ConnectionCount)
 		return false;
 
 	//Create a new map node and fill it with parameters
 	QVariantMap telescope;
 	telescope.insert("name", name);
 	telescope.insert("connection", connectionTypeNames.value(connectionType));
+	telescope.insert("equinox", equinox);//TODO: Validation!
 
 	if (connectionType == ConnectionRemote)
 	{
@@ -1016,7 +989,7 @@ bool TelescopeControl::addTelescopeAtSlot(int slot, ConnectionType connectionTyp
 	return true;
 }
 
-bool TelescopeControl::getTelescopeAtSlot(int slot, ConnectionType& connectionType, QString& name, QString& host, int& portTCP, int& delay, bool& connectAtStartup, QList<double>& circles, QString& deviceModelName, QString& portSerial)
+bool TelescopeControl::getTelescopeAtSlot(int slot, ConnectionType& connectionType, QString& name, QString& equinox, QString& host, int& portTCP, int& delay, bool& connectAtStartup, QList<double>& circles, QString& deviceModelName, QString& portSerial)
 {
 	//Validation
 	if(!isValidSlotNumber(slot))
@@ -1032,6 +1005,7 @@ bool TelescopeControl::getTelescopeAtSlot(int slot, ConnectionType& connectionTy
 
 	//Read the parameters
 	name = telescope.value("name").toString();
+	equinox = telescope.value("equinox", "J2000").toString();
 	host = telescope.value("host_name").toString();
 	portTCP = telescope.value("tcp_port").toInt();
 	delay = telescope.value("delay", DEFAULT_DELAY).toInt();
@@ -1073,6 +1047,7 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 
 	//Read the telescope properties
 	QString name;
+	QString equinox;
 	QString host;
 	ConnectionType connectionType;
 	int portTCP;
@@ -1081,7 +1056,7 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 	QList<double> circles;
 	QString deviceModelName;
 	QString portSerial;
-	if(!getTelescopeAtSlot(slot, connectionType, name, host, portTCP, delay, connectAtStartup, circles, deviceModelName, portSerial))
+	if(!getTelescopeAtSlot(slot, connectionType, name, equinox, host, portTCP, delay, connectAtStartup, circles, deviceModelName, portSerial))
 	{
 		//TODO: Add debug
 		return false;
@@ -1091,7 +1066,7 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 	{
 		if(deviceModels[deviceModelName].useExecutable)
 		{
-			if (startClientAtSlot(slot, connectionType, name, host, portTCP, delay, circles))
+			if (startClientAtSlot(slot, connectionType, name, equinox, host, portTCP, delay, circles))
 			{
 				if(!startServerAtSlot(slot, deviceModelName, portTCP, portSerial))
 				{
@@ -1108,7 +1083,7 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 		{
 			addLogAtSlot(slot);
 			logAtSlot(slot);
-			if (startClientAtSlot(slot, connectionType, name, QString(), 0, delay, circles, deviceModelName, portSerial))
+			if (startClientAtSlot(slot, connectionType, name, equinox, QString(), 0, delay, circles, deviceModelName, portSerial))
 			{
 				emit clientConnected(slot, name);
 				return true;
@@ -1117,7 +1092,7 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 	}
 	else
 	{
-		if (startClientAtSlot(slot, connectionType, name, host, portTCP, delay, circles))
+		if (startClientAtSlot(slot, connectionType, name, equinox, host, portTCP, delay, circles))
 		{
 			emit clientConnected(slot, name);
 			return true;
@@ -1212,9 +1187,9 @@ bool TelescopeControl::startServerAtSlot(int slotNumber, QString deviceModelName
 		#ifdef Q_OS_WIN32
 		QString serialPortName;
 		if(portSerial.right(portSerial.size() - SERIAL_PORT_PREFIX.size()).toInt() > 9)
-			serialPortName = "\\\\.\\" + portSerial + ":";//"\\.\COMxx", not sure if it will work
+			serialPortName = "\\\\.\\" + portSerial;//"\\.\COMxx", not sure if it will work
 		else
-			serialPortName = portSerial + ":";
+			serialPortName = portSerial;
 		#else
 		QString serialPortName = portSerial;
 		#endif //Q_OS_WIN32
@@ -1260,7 +1235,7 @@ bool TelescopeControl::stopServerAtSlot(int slotNumber)
 	return true;
 }
 
-bool TelescopeControl::startClientAtSlot(int slotNumber, ConnectionType connectionType, QString name, QString host, int portTCP, int delay, QList<double> circles, QString deviceModelName, QString portSerial)
+bool TelescopeControl::startClientAtSlot(int slotNumber, ConnectionType connectionType, QString name, QString equinox, QString host, int portTCP, int delay, QList<double> circles, QString deviceModelName, QString portSerial)
 {
 	//Validation
 	if(!isValidSlotNumber(slotNumber))
@@ -1278,26 +1253,26 @@ bool TelescopeControl::startClientAtSlot(int slotNumber, ConnectionType connecti
 	switch (connectionType)
 	{
 	case ConnectionVirtual:
-		initString = QString("%1:%2").arg(name, "TelescopeServerDummy");
+		initString = QString("%1:%2:%3").arg(name, "TelescopeServerDummy", "J2000");
 		break;
 
 	case ConnectionInternal:
 		if(!deviceModelName.isEmpty() && !portSerial.isEmpty())
-			initString = QString("%1:%2:%3:%4").arg(name, deviceModels[deviceModelName].server, portSerial, QString::number(delay));
+			initString = QString("%1:%2:%3:%4:%5").arg(name, deviceModels[deviceModelName].server, equinox, portSerial, QString::number(delay));
 		break;
 
 	case ConnectionLocal:
 		if (isValidPort(portTCP))
-			initString = QString("%1:TCP:%2:%3:%4").arg(name, "localhost", QString::number(portTCP), QString::number(delay));
+			initString = QString("%1:TCP:%2:%3:%4:%5").arg(name, equinox, "localhost", QString::number(portTCP), QString::number(delay));
 		break;
 
 	case ConnectionRemote:
 	default:
 		if (isValidPort(portTCP) && !host.isEmpty())
-			initString = QString("%1:TCP:%2:%3:%4").arg(name, host, QString::number(portTCP), QString::number(delay));
+			initString = QString("%1:TCP:%2:%3:%4:%5").arg(name, equinox, host, QString::number(portTCP), QString::number(delay));
 	}
 
-	qDebug() << "initString:" << initString;
+	//qDebug() << "initString:" << initString;
 
 	TelescopeClient* newTelescope = TelescopeClient::create(initString);
 	if (newTelescope)
@@ -1529,20 +1504,6 @@ bool TelescopeControl::restoreDeviceModelsListTo(QString deviceModelsListPath)
 	return true;
 }
 
-const StelStyle TelescopeControl::getModuleStyleSheet(const StelStyle& style)
-{
-	StelStyle pluginStyle(style);
-	if (style.confSectionName == "color")
-	{
-		pluginStyle.qtStyleSheet.append(*normalStyleSheet);
-	}
-	else
-	{
-		pluginStyle.qtStyleSheet.append(*nightStyleSheet);
-	}
-	return pluginStyle;
-}
-
 const QString& TelescopeControl::getServerExecutablesDirectoryPath()
 {
 	return serverExecutablesDirectoryPath;
