@@ -221,9 +221,11 @@ void StelApp::init(QSettings* conf)
 	textureMgr->init();
 
 #ifdef BUILD_FOR_MAEMO
-	StelLoadingBar loadingBar("textures/logoMaemo.png", "", 25, 320, 101, 800, 480);
+	StelLoadingBar loadingBar("textures/logoMaemo.png", PACKAGE_VERSION, 25, 520, 101, 800, 480);
 #else
- #ifdef SVN_REVISION
+ #ifdef BZR_REVISION
+	StelLoadingBar loadingBar("textures/logo24bits.png", QString("BZR r%1").arg(BZR_REVISION), 25, 320, 101);
+ #elif SVN_REVISION
 	StelLoadingBar loadingBar("textures/logo24bits.png", QString("SVN r%1").arg(SVN_REVISION), 25, 320, 101);
  #else
 	StelLoadingBar loadingBar("textures/logo24bits.png", PACKAGE_VERSION, 45, 320, 121);
