@@ -34,6 +34,7 @@
 #include <QStringList>
 #include <QDateTime>
 #include <QDebug>
+#include <QRegExp>
 
 // Init statics transfo matrices
 // See vsop87.doc:
@@ -58,8 +59,14 @@ void StelNavigator::init()
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
 
-	defaultLocationID = conf->value("init_location/location","Paris, Paris, France").toString();
-	position = new StelObserver(StelApp::getInstance().getLocationMgr().locationForSmallString(defaultLocationID));
+	defaultLocationID = conf->value("init_location/location","error").toString();
+	bool ok;
+	StelLocation location = StelApp::getInstance().getLocationMgr().locationForString(defaultLocationID, &ok);
+	if (!ok)
+	{
+		qWarning() << "Warning: location" << defaultLocationID << "is unknown.";
+	}
+	position = new StelObserver(location);
 
 	setTimeNow();
 	// Compute transform matrices between coordinates systems
@@ -67,7 +74,6 @@ void StelNavigator::init()
 
 	// we want to be able to handle the old style preset time, recorded as a double
 	// jday, or as a more human readable string...
-	bool ok;
 	QString presetTimeStr = conf->value("navigation/preset_sky_time",2451545.).toString();
 	presetSkyTime = presetTimeStr.toDouble(&ok);
 	if (ok)
