@@ -39,22 +39,22 @@ bool StelProjectorPerspective::backward(Vec3d &v) const
 	return true;
 }
 
-double StelProjectorPerspective::fovToViewScalingFactor(double fov) const
+float StelProjectorPerspective::fovToViewScalingFactor(float fov) const
 {
 	return std::tan(fov);
 }
 
-double StelProjectorPerspective::viewScalingFactorToFov(double vsf) const
+float StelProjectorPerspective::viewScalingFactorToFov(float vsf) const
 {
 	return std::atan(vsf);
 }
 
-double StelProjectorPerspective::deltaZoom(double fov) const
+float StelProjectorPerspective::deltaZoom(float fov) const
 {
-    const double vsf = fovToViewScalingFactor(fov);
+	const float vsf = fovToViewScalingFactor(fov);
 // deriv_viewScalingFactorToFov(vsf) = 1.0 / (1.0+vsf*vsf)
 // return vsf*deriv_viewScalingFactorToFov(vsf))
-	return vsf / (1.0+vsf*vsf);
+	return vsf / (1.f+vsf*vsf);
 }
 
 
@@ -88,22 +88,19 @@ bool StelProjectorEqualArea::backward(Vec3d &v) const
 	return true;
 }
 
-double StelProjectorEqualArea::fovToViewScalingFactor(double fov) const
+float StelProjectorEqualArea::fovToViewScalingFactor(float fov) const
 {
-	return 2.0 * std::sin(0.5 * fov);
+	return 2.f * std::sin(0.5f * fov);
 }
 
-double StelProjectorEqualArea::viewScalingFactorToFov(double vsf) const
+float StelProjectorEqualArea::viewScalingFactorToFov(float vsf) const
 {
-	return 2.0 * std::asin(0.5 * vsf);
+	return 2.f * std::asin(0.5f * vsf);
 }
 
-double StelProjectorEqualArea::deltaZoom(double fov) const
+float StelProjectorEqualArea::deltaZoom(float fov) const
 {
-// deriv_viewScalingFactorToFov(vsf) = 2.0 / sqrt(4.0-vsf*vsf);
-// const double vsf = fovToViewScalingFactor(fov);
-// return vsf*deriv_viewScalingFactorToFov(vsf)) = 2.0*vsf / sqrt(4.0-vsf*vsf);
-    return fov;
+	return fov;
 }
 
 QString StelProjectorStereographic::getNameI18() const
@@ -124,22 +121,20 @@ bool StelProjectorStereographic::backward(Vec3d &v) const
   return true;
 }
 
-double StelProjectorStereographic::fovToViewScalingFactor(double fov) const
+float StelProjectorStereographic::fovToViewScalingFactor(float fov) const
 {
-	return 2.0 * std::tan(0.5 * fov);
+	return 2.f * std::tan(0.5f * fov);
 }
 
-double StelProjectorStereographic::viewScalingFactorToFov(double vsf) const
+float StelProjectorStereographic::viewScalingFactorToFov(float vsf) const
 {
-	return 2.0 * std::atan(0.5 * vsf);
+	return 2.f * std::atan(0.5f * vsf);
 }
 
-double StelProjectorStereographic::deltaZoom(double fov) const
+float StelProjectorStereographic::deltaZoom(float fov) const
 {
-    const double vsf = fovToViewScalingFactor(fov);
-// deriv_viewScalingFactorToFov(vsf) = 4.0 / (4.0+vsf*vsf)
-// return vsf*deriv_viewScalingFactorToFov(vsf))
-	return 4.0*vsf / (4.0+vsf*vsf);
+	const float vsf = fovToViewScalingFactor(fov);
+	return 4.f*vsf / (4.f+vsf*vsf);
 }
 
 
@@ -165,25 +160,23 @@ bool StelProjectorFisheye::backward(Vec3d &v) const
 	return (a < M_PI);
 }
 
-double StelProjectorFisheye::fovToViewScalingFactor(double fov) const
+float StelProjectorFisheye::fovToViewScalingFactor(float fov) const
 {
 	return fov;
 }
 
-double StelProjectorFisheye::viewScalingFactorToFov(double vsf) const
+float StelProjectorFisheye::viewScalingFactorToFov(float vsf) const
 {
 	return vsf;
 }
 
-double StelProjectorFisheye::deltaZoom(double fov) const
+float StelProjectorFisheye::deltaZoom(float fov) const
 {
 	return fov;
 }
 
 
 
-
-
 QString StelProjectorHammer::getNameI18() const
 {
 	return q_("Hammer-Aitoff");
@@ -208,17 +201,17 @@ bool StelProjectorHammer::backward(Vec3d &v) const
 	return ret;
 }
 
-double StelProjectorHammer::fovToViewScalingFactor(double fov) const
+float StelProjectorHammer::fovToViewScalingFactor(float fov) const
 {
 	return fov;
 }
 
-double StelProjectorHammer::viewScalingFactorToFov(double vsf) const
+float StelProjectorHammer::viewScalingFactorToFov(float vsf) const
 {
 	return vsf;
 }
 
-double StelProjectorHammer::deltaZoom(double fov) const
+float StelProjectorHammer::deltaZoom(float fov) const
 {
 	return fov;
 }
@@ -235,12 +228,12 @@ QString StelProjectorCylinder::getDescriptionI18() const
 	return q_("The full name of this projection mode is <i>cylindrical equidistant projection</i>. With this projection all parallels are equally spaced.");
 }
 
-bool StelProjectorCylinder::forward(Vec3d &v) const
+bool StelProjectorCylinder::forward(Vec3f &v) const
 {
-	const double r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
+	const float r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
 	const bool rval = (-r < v[1] && v[1] < r);
-	const double alpha = std::atan2(v[0],-v[2]);
-	const double delta = std::asin(v[1]/r);
+	const float alpha = std::atan2(v[0],-v[2]);
+	const float delta = std::asin(v[1]/r);
 	v[0] = alpha;
 	v[1] = delta;
 	v[2] = r;
@@ -257,17 +250,17 @@ bool StelProjectorCylinder::backward(Vec3d &v) const
 	return rval;
 }
 
-double StelProjectorCylinder::fovToViewScalingFactor(double fov) const
+float StelProjectorCylinder::fovToViewScalingFactor(float fov) const
 {
 	return fov;
 }
 
-double StelProjectorCylinder::viewScalingFactorToFov(double vsf) const
+float StelProjectorCylinder::viewScalingFactorToFov(float vsf) const
 {
 	return vsf;
 }
 
-double StelProjectorCylinder::deltaZoom(double fov) const
+float StelProjectorCylinder::deltaZoom(float fov) const
 {
 	return fov;
 }
@@ -282,13 +275,13 @@ QString StelProjectorMercator::getDescriptionI18() const
 	return q_("The mercator projection is one of the most used world map projection. It preserves direction and shapes but distorts size, in an increasing degree away from the equator.");
 }
 
-bool StelProjectorMercator::forward(Vec3d &v) const
+bool StelProjectorMercator::forward(Vec3f &v) const
 {
-	const double r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
+	const float r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
 	const bool rval = (-r < v[1] && v[1] < r);
-	const double sin_delta = v[1]/r;
+	const float sin_delta = v[1]/r;
 	v[0] = std::atan2(v[0],-v[2]);
-	v[1] = 0.5*std::log((1.0+sin_delta)/(1.0-sin_delta));
+	v[1] = 0.5f*std::log((1.f+sin_delta)/(1.f-sin_delta));
 	v[2] = r;
 	return rval;
 }
@@ -308,17 +301,17 @@ bool StelProjectorMercator::backward(Vec3d &v) const
 	return rval;
 }
 
-double StelProjectorMercator::fovToViewScalingFactor(double fov) const
+float StelProjectorMercator::fovToViewScalingFactor(float fov) const
 {
 	return fov;
 }
 
-double StelProjectorMercator::viewScalingFactorToFov(double vsf) const
+float StelProjectorMercator::viewScalingFactorToFov(float vsf) const
 {
 	return vsf;
 }
 
-double StelProjectorMercator::deltaZoom(double fov) const
+float StelProjectorMercator::deltaZoom(float fov) const
 {
 	return fov;
 }
@@ -334,13 +327,13 @@ QString StelProjectorOrthographic::getDescriptionI18() const
 	return q_("Orthographic projection is related to perspective projection, but the point of perspective is set to an infinite distance.");
 }
 
-bool StelProjectorOrthographic::forward(Vec3d &v) const
+bool StelProjectorOrthographic::forward(Vec3f &v) const
 {
-	const double r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
-	const double h = 1.0/r;
+	const float r = std::sqrt(v[0]*v[0] + v[1]*v[1] + v[2]*v[2]);
+	const float h = 1.f/r;
 	v[0] *= h;
 	v[1] *= h;
-	const bool rval = (v[2] <= 0.0);
+	const bool rval = (v[2] <= 0.f);
 	v[2] = r;
 	return rval;
 }
@@ -360,17 +353,17 @@ bool StelProjectorOrthographic::backward(Vec3d &v) const
 	return true;
 }
 
-double StelProjectorOrthographic::fovToViewScalingFactor(double fov) const
+float StelProjectorOrthographic::fovToViewScalingFactor(float fov) const
 {
 	return std::sin(fov);
 }
 
-double StelProjectorOrthographic::viewScalingFactorToFov(double vsf) const
+float StelProjectorOrthographic::viewScalingFactorToFov(float vsf) const
 {
 	return std::asin(vsf);
 }
 
-double StelProjectorOrthographic::deltaZoom(double fov) const
+float StelProjectorOrthographic::deltaZoom(float fov) const
 {
 	return fov;
 }
@@ -387,30 +380,31 @@ QString StelProjector2d::getDescriptionI18() const
 	return "Simple 2d projection for internal use.";
 }
 
-bool StelProjector2d::forward(Vec3d &v) const
+bool StelProjector2d::forward(Vec3f &) const
 {
 	Q_ASSERT(0);
 	return false;
 }
 
-bool StelProjector2d::backward(Vec3d &v) const
+bool StelProjector2d::backward(Vec3d &) const
 {
 	Q_ASSERT(0);
 	return false;
 }
 
-double StelProjector2d::fovToViewScalingFactor(double fov) const
+float StelProjector2d::fovToViewScalingFactor(float) const
 {
-	return 1.;
+	return 1.f;
 }
 
-double StelProjector2d::viewScalingFactorToFov(double vsf) const
+float StelProjector2d::viewScalingFactorToFov(float) const
 {
-	return 1.;
+	return 1.f;
 }
 
-double StelProjector2d::deltaZoom(double fov) const
+float StelProjector2d::deltaZoom(float fov) const
 {
 	Q_ASSERT(0);
 	return fov;
 }
+
