@@ -511,7 +511,8 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 				continue;
 			}
 
-			englishCommonName.replace('_', ' ');
+			// Fix for translate star names 
+			// englishCommonName.replace('_', ' ');
 			const QString commonNameI18n = q_(englishCommonName);
 			QString commonNameI18n_cap = commonNameI18n.toUpper();
 
@@ -763,13 +764,17 @@ QList<StelObjectP > StarMgr::searchAround(const Vec3d& vv, double limFov, const
 //! The translation is done using gettext with translated strings defined in translations.h
 void StarMgr::updateI18n()
 {
+	QRegExp transRx("_[(]\"(.*)\"[)]");
 	StelTranslator trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
 	commonNamesMapI18n.clear();
 	commonNamesIndexI18n.clear();
 	for (QHash<int,QString>::ConstIterator it(commonNamesMap.constBegin());it!=commonNamesMap.constEnd();it++)
 	{
 		const int i = it.key();
-		const QString t(trans.qtranslate(it.value()));
+		transRx.exactMatch(it.value());
+		QString tt = transRx.capturedTexts().at(1);
+		const QString t = trans.qtranslate(tt);
+		//const QString t(trans.qtranslate(it.value()));
 		commonNamesMapI18n[i] = t;
 		commonNamesIndexI18n[t.toUpper()] = i;
 	}
