@@ -52,6 +52,8 @@ private:
 	QVariantMap nextStarCatalogToDownload;
 	//! Set the content of the "Star catalog updates" box
 	void refreshStarCatalogButton();
+	//! True when at least one star catalog has been downloaded successfully this session
+	bool hasDownloadedStarCatalog;
 	QNetworkReply* starCatalogDownloadReply;
 	QFile* currentDownloadFile;
 	QProgressBar* progressBar;
@@ -61,11 +63,11 @@ private slots:
 	void setAllSelectedInfo(void);
 	void setBriefSelectedInfo(void);
 	void languageChanged(const QString& languageCode);
-	void setStartupTimeMode(void);
+	void setStartupTimeMode();
 	void setDiskViewport(bool);
 	void setSphericMirror(bool);
 	void cursorTimeOutChanged();
-	void cursorTimeOutChanged(double d) {cursorTimeOutChanged();}
+	void cursorTimeOutChanged(double) {cursorTimeOutChanged();}
 
 	void newStarCatalogData();
 	void downloadStars();
@@ -91,9 +93,9 @@ private slots:
 	//! This basically replaces the config.ini by the default one
 	void setDefaultViewOptions();
 
-	void populatePluginsList(void);
+	void populatePluginsList();
 	void pluginsSelectionChanged(const QString&);
-	void pluginConfigureCurrentSelection(void);
+	void pluginConfigureCurrentSelection();
 	void loadAtStartupChanged(int);
 
 	//! The selection of script in the script list has changed
@@ -101,15 +103,15 @@ private slots:
 	void scriptSelectionChanged(const QString& s);
 
 	//! Run the currently selected script from the script list.
-	void runScriptClicked(void);
+	void runScriptClicked();
 	//! Stop the currently running script.
-	void stopScriptClicked(void);
+	void stopScriptClicked();
 
-	void aScriptIsRunning(void);
-	void aScriptHasStopped(void);
+	void aScriptIsRunning();
+	void aScriptHasStopped();
 
-	void populateScriptsList(void);
-	void setFixedDateTimeToCurrent(void);
+	void populateScriptsList();
+	void setFixedDateTimeToCurrent();
 
 	void changePage(QListWidgetItem *current, QListWidgetItem *previous);
 
